@@ -41,5 +41,5 @@ class MysqlPool(BaseConnectionPool):
                         passwd=self.conn_info.password, db=self.conn_info.db_name,
                         mincached=self.conn_info.min_size, maxcached=self.conn_info.max_size,
                         ping=1, maxconnections=self.conn_info.max_size, maxshared=self.conn_info.max_size,
-                        maxusage=self.conn_info.max_size, charset="utf8", autocommit=True)
+                        maxusage=self.conn_info.min_size, charset="utf8mb4", autocommit=True)
         return pool
