@@ -22,7 +22,7 @@ class MysqlSqlAlchemyPool(BaseConnectionPool):
     """
 
     def sync_create_pool(self):
-        mysql_url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8'.format(
+        mysql_url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
             self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
             self.conn_info.db_name)
         db = SQLAlchemy(mysql_url, engine_options={"echo": True, "pool_recycle": 3600})
